# Backdrop

JavaScript object that adds the ability to highlight elements in the document via backdrop.

[![npm](https://img.shields.io/npm/v/@fczbkk/backdrop.svg?maxAge=2592000)](https://www.npmjs.com/package/@fczbkk/backdrop)
[![npm](https://img.shields.io/github/license/fczbkk/backdrop.svg?maxAge=2592000)](https://github.com/fczbkk/backdrop/blob/master/LICENSE)
[![David](https://img.shields.io/david/fczbkk/backdrop.svg?maxAge=2592000)](https://david-dm.org/fczbkk/backdrop)
[![Travis](https://img.shields.io/travis/fczbkk/backdrop.svg?maxAge=2592000)](https://travis-ci.org/fczbkk/backdrop)

## How to use

Install the library via NPM:

```shell
npm install @fczbkk/backdrop --save
```

Then use in your project like this:

```javascript
import Backdrop from '@fczbkk/backdrop';

// create instance of Backdrop object
var my_backdrop = new Backdrop();

// show backdrop around target element
my_backdrop.add('#myElement');
my_backdrop.show();

// hide the backdrop
my_backdrop.hide();
```

## Documentation

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### default_options

Config object for Backdrop.

**Properties**

-   `backdrop_class` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** `"backdrop"` Class name added to all backdrop elements.
-   `z_index` **[number](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number)** `1000` Z-index added to all backdrop elements.
-   `padding` **[number](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number)** `5` Size of padding around target elements, in pixels.
-   `color` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** `"#000000"` Color of the backdrop elements.
-   `opacity` **[number](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number)** `0.5` Opacity of the backdrop elements. Must be number between 1 (fully opaque) and 0 (no opacity).
-   `hide_on_click` **[boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** `true` If true, the backdrop will hide when user clicks on it.
-   `cover` **[boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** `false` If true, the target elements will be covered by invisible elements which will prevent user from clicking on them. The cover elements also react to click when `hide_on_click` is enabled.
-   `watch` **[boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** `false` If true, the backdrop will watch target elements and react to the changes in their position, size and/or visibility. This feature can have impact on performance, so it is turned off by default.
-   `watch_interval` **[number](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number)** `500` Interval between checks when watching for changes, in milliseconds.
-   `onShow` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** Function to be called when backdrop is shown.
-   `onHide` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** Function to be called when backdrop is hidden.

### Backdrop

Class representing a Backdrop.

**Parameters**

-   `custom_options`   (optional, default `{}`)

#### constructor

Create a Backdrop object.

**Parameters**

-   `custom_options` **BackdropOptions**  (optional, default `{}`)

#### setOptions

Updates existing options.

**Parameters**

-   `custom_options` **BackdropOptions**  (optional, default `{}`)

#### add

Adds element(s) to target elements.

**Parameters**

-   `element` **([Element](https://developer.mozilla.org/en-US/docs/Web/API/Element) \| [string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String))** Reference to an element or CSS selector.

#### remove

Removes element(s) from target elements.

**Parameters**

-   `element` **([Element](https://developer.mozilla.org/en-US/docs/Web/API/Element) \| [string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String))** Reference to an element or CSS selector.

#### set

Sets new target element(s).

**Parameters**

-   `element` **([Element](https://developer.mozilla.org/en-US/docs/Web/API/Element) \| [string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String))** Reference to an element or CSS selector.

#### show

Shows backdrop. If element is provided, it is set before backdrop is shown.

**Parameters**

-   `element` **([Element](https://developer.mozilla.org/en-US/docs/Web/API/Element) \| [string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String))?** Reference to an element or CSS selector.

#### hide

Hides backdrop.

#### destroy

Removes backdrop from document.

## Bug reports, feature requests and contact

If you found any bugs, if you have feature requests or any questions, please, either [file an issue at GitHub](https://github.com/fczbkk/backdrop/issues) or send me an e-mail at <a href="mailto:riki@fczbkk.com">riki@fczbkk.com</a>.

## License

Backdrop is published under the [MIT license](https://github.com/fczbkk/backdrop/blob/master/LICENSE).
